@@ -19,21 +19,22 @@
 plotProfiles <- function(ip, data, var, trans, tvar, gvar,
                          auto.layout=TRUE, lines=TRUE, points=FALSE, add=FALSE,
                          xlab="Time", ylab, xaxt="s", yaxt="s", xlim, ylim, main,
-                         col, bg, lty=1, lwd=1, pch=21,
+                         lcol, col, bg, lty=1, lwd=1, pch=21,
                          cex.points=1,
                          highlight, lines.highlight=TRUE, points.highlight=TRUE,
-                         col.highlight="red3", bg.highlight="orange",
+                         lcol.highlight="red3", col.highlight="red3", bg.highlight="orange",
                          lty.highlight=1, lwd.highlight=2, pch.highlight=23,
                          cex.highlight=1)
 {   
   if (lines){
-    if (missing(col)) col <- rainbow_hcl(1, start=230, c=40)
+    if (missing(col)) col <- rainbow_hcl(1, start = 230, c = 40)
   }
 
   if (points){
-    if (missing(col)) col <- "darkblue"
-  }    
-  if (missing(bg)) bg <- rainbow_hcl(1, start=230, c=40)
+    if (missing(col)) col <- "darkblue"    
+  }
+  if (missing(lcol)) lcol <- col  
+  if (missing(bg)) bg <- rainbow_hcl(1, start = 230, c = 40)
   
   if (missing(xlim)){
     xlim <- range(data[, tvar], na.rm=TRUE)
@@ -55,13 +56,16 @@ plotProfiles <- function(ip, data, var, trans, tvar, gvar,
     GROUP <- levels(data[, gvar])
     if (length(col) == 1){
       if (length(bg) == 1) col <- rainbow_hcl(length(GROUP)) else col <- rep(col, length(GROUP))     
-    }  
+    }
+    if (length(lcol) == 1) lcol <- rainbow_hcl(length(GROUP))
     if (length(col) != length(GROUP)) stop("incorrect col supplied")
+    if (length(lcol) != length(GROUP)) stop("incorrect lcol supplied")    
     if (length(bg) == 1) bg <- rainbow_hcl(length(GROUP))
     if (length(bg) != length(GROUP)) stop("incorrect bg supplied")    
-    names(col) <- names(bg) <- GROUP
+    names(col) <- names(bg) <- names(lcol) <- GROUP
   }else{
     col <- col[1]
+    lcol <- lcol[1]
   }  
   
   if (auto.layout & !add){
@@ -73,16 +77,18 @@ plotProfiles <- function(ip, data, var, trans, tvar, gvar,
   for (i in 1:length(ip)){
     if (!missing(gvar)){
       COL <- col[ip[[i]][1, gvar]]
-      BG <- bg[ip[[i]][1, gvar]]      
+      BG <- bg[ip[[i]][1, gvar]]
+      LCOL <- lcol[ip[[i]][1, gvar]]      
     }else{
       COL <- col[1]
       BG <- bg[1]
+      LCOL <- lcol[1]
     }  
     if (missing(trans)){
-      if (lines) lines(ip[[i]][, tvar], ip[[i]][, var], col=COL, lty=lty, lwd=lwd)
+      if (lines) lines(ip[[i]][, tvar], ip[[i]][, var], col=LCOL, lty=lty, lwd=lwd)
       if (points) points(ip[[i]][, tvar], ip[[i]][, var], col=COL, bg=BG, pch=pch, cex=cex.points)
     }else{  
-      if (lines) lines(ip[[i]][, tvar], trans(ip[[i]][, var]), col=COL, lty=lty, lwd=lwd)
+      if (lines) lines(ip[[i]][, tvar], trans(ip[[i]][, var]), col=LCOL, lty=lty, lwd=lwd)
       if (points) points(ip[[i]][, tvar], trans(ip[[i]][, var]), col=COL, bg=BG, pch=pch, cex=cex.points)      
     }  
   }
@@ -95,10 +101,10 @@ plotProfiles <- function(ip, data, var, trans, tvar, gvar,
         next
       }
       if (missing(trans)){
-        if (lines.highlight)  lines(ip[[hh]][, tvar], ip[[hh]][, var],  col=col.highlight, lty=lty.highlight, lwd=lwd.highlight)
+        if (lines.highlight)  lines(ip[[hh]][, tvar], ip[[hh]][, var],  col=lcol.highlight, lty=lty.highlight, lwd=lwd.highlight)
         if (points.highlight) points(ip[[hh]][, tvar], ip[[hh]][, var], col=col.highlight, bg=bg.highlight, pch=pch.highlight, cex=cex.highlight)
       }else{
-        if (lines.highlight)  lines(ip[[hh]][, tvar], trans(ip[[hh]][, var]),  col=col.highlight, lty=lty.highlight, lwd=lwd.highlight)
+        if (lines.highlight)  lines(ip[[hh]][, tvar], trans(ip[[hh]][, var]),  col=lcol.highlight, lty=lty.highlight, lwd=lwd.highlight)
         if (points.highlight) points(ip[[hh]][, tvar], trans(ip[[hh]][, var]), col=col.highlight, bg=bg.highlight, pch=pch.highlight, cex=cex.highlight)
       }  
     }  
